@@ -26,6 +26,9 @@ instance HasLabel Okta
 instance HasTokenReq Okta where
   tokenReq _ mgr = fetchAccessToken mgr oktaKey
 
+instance HasTokenRefreshReq Okta where
+  tokenRefreshReq _ mgr = refreshAccessToken mgr oktaKey
+
 instance HasUserReq Okta where
   userReq _ mgr at = do
     re <- authGetJSON mgr at userInfoUri
@@ -33,8 +36,8 @@ instance HasUserReq Okta where
 
 instance HasAuthUri Okta where
   authUri _ = createCodeUri oktaKey [ ("state", "Okta.test-state-123")
-                                        , ("scope", "openid profile")
-                                        ]
+                                    , ("scope", "openid profile offline_access")
+                                    ]
 
 data OktaUser = OktaUser { name              :: Text
                          , preferredUsername :: Text
