@@ -9,10 +9,11 @@
 module IDP.StackExchange where
 import           Data.Aeson
 import           Data.Bifunctor
-import           Data.ByteString      (ByteString)
+import           Data.ByteString            (ByteString)
+import qualified Data.ByteString.Lazy.Char8 as BSL
 import           Data.Hashable
-import           Data.Text.Lazy       (Text)
-import qualified Data.Text.Lazy       as TL
+import           Data.Text.Lazy             (Text)
+import qualified Data.Text.Lazy             as TL
 import           GHC.Generics
 import           Keys
 import           Lens.Micro
@@ -33,12 +34,14 @@ instance HasLabel StackExchange
 instance HasTokenReq StackExchange where
   tokenReq _ mgr = fetchAccessToken2 mgr stackexchangeKey
 
+instance HasTokenRefreshReq StackExchange where
+  tokenRefreshReq _ mgr = refreshAccessToken mgr stackexchangeKey
+
 instance HasUserReq StackExchange where
   userReq _ mgr token = do
-    re <- parseResponseJSON
-          <$> authGetBS2 mgr token
+    re <- authGetBS2 mgr token
               (userInfoUri `appendStackExchangeAppKey` stackexchangeAppKey)
-    return (second toLoginUser re)
+    return (re >>= (bimap BSL.pack toLoginUser . eitherDecode))
 
 instance HasAuthUri StackExchange where
   authUri _ = createCodeUri stackexchangeKey [ ("state", "StackExchange.test-state-123")
@@ -72,4 +75,3 @@ toLoginUser StackExchangeResp {..} =
 appendStackExchangeAppKey :: URI -> ByteString -> URI
 appendStackExchangeAppKey useruri k =
   over (queryL . queryPairsL) (\query -> query ++ [("key", k)]) useruri
-
