@@ -5,9 +5,10 @@
 module IDP.Weibo where
 import           Data.Aeson
 import           Data.Bifunctor
+import qualified Data.ByteString.Lazy.Char8 as BSL
 import           Data.Hashable
-import           Data.Text.Lazy       (Text)
-import qualified Data.Text.Lazy       as TL
+import           Data.Text.Lazy             (Text)
+import qualified Data.Text.Lazy             as TL
 import           GHC.Generics
 import           Keys
 import           Network.OAuth.OAuth2
@@ -24,6 +25,9 @@ instance IDP Weibo
 
 instance HasLabel Weibo
 
+instance HasTokenRefreshReq Weibo where
+  tokenRefreshReq _ mgr = refreshAccessToken mgr weiboKey
+
 instance HasTokenReq Weibo where
   tokenReq _ mgr = fetchAccessToken mgr weiboKey
 
@@ -32,8 +36,8 @@ instance HasTokenReq Weibo where
 -- access token in query param only
 instance HasUserReq Weibo where
   userReq _ mgr at = do
-    re <- parseResponseJSON <$> authGetBS2 mgr at userInfoUri
-    return (second toLoginUser re)
+    re <- authGetBS2 mgr at userInfoUri
+    return (re >>= (bimap BSL.pack toLoginUser . eitherDecode))
 
 instance HasAuthUri Weibo where
   authUri _ = createCodeUri weiboKey [ ("state", "Weibo.test-state-123")
