@@ -9,6 +9,7 @@ module Types where
 
 import           Control.Concurrent.MVar
 import           Data.Aeson
+import qualified Data.ByteString.Lazy.Char8        as BSL
 import           Data.Hashable
 import qualified Data.HashMap.Strict               as Map
 import           Data.Maybe
@@ -41,13 +42,21 @@ class (IDP a) => HasAuthUri a where
 class (IDP a) => HasTokenReq a where
   tokenReq :: a -> Manager -> ExchangeToken -> IO (OAuth2Result TR.Errors OAuth2Token)
 
+class (IDP a) => HasTokenRefreshReq a where
+  tokenRefreshReq :: a -> Manager -> RefreshToken -> IO (OAuth2Result TR.Errors OAuth2Token)
+
 class (IDP a) => HasUserReq a where
-  userReq :: FromJSON b => a -> Manager -> AccessToken -> IO (OAuth2Result b LoginUser)
+  userReq :: a -> Manager -> AccessToken -> IO (Either BSL.ByteString LoginUser)
 
 -- Heterogenous collections
 -- https://wiki.haskell.org/Heterogenous_collections
 --
-data IDPApp = forall a. (IDP a, HasTokenReq a, HasUserReq a, HasLabel a, HasAuthUri a) => IDPApp a
+data IDPApp = forall a. (IDP a,
+                         HasTokenRefreshReq a,
+                         HasTokenReq a,
+                         HasUserReq a,
+                         HasLabel a,
+                         HasAuthUri a) => IDPApp a
 
 -- dummy oauth2 request error
 --
@@ -65,6 +74,7 @@ newtype LoginUser =
 data IDPData =
   IDPData { codeFlowUri     :: Text
           , loginUser       :: Maybe LoginUser
+          , oauth2Token     :: Maybe OAuth2Token
           , idpDisplayLabel :: IDPLabel
           }
 
